.. picuplib documentation master file, created by
   sphinx-quickstart on Tue Aug 12 20:56:16 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to picuplib's documentation!
====================================
picuplib is a simple library for uploading Picture, directly and remote, to Picflash.org

Contents:

.. toctree::
   :maxdepth: 2

   api




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

